OC.L10N.register(
    "settings",
    {
    "__language_name__" : "__ਭਾਸ਼ਾ_ਨਾਂ__",
    "Language changed" : "ਭਾਸ਼ਾ ਬਦਲੀ",
    "Please wait...." : "...ਉਡੀਕੋ ਜੀ",
    "Disable" : "ਬੰਦ",
    "Enable" : "ਚਾਲੂ",
    "Updating...." : "...ਅੱਪਡੇਟ ਕੀਤਾ ਜਾ ਰਿਹਾ ਹੈ",
    "Updated" : "ਅੱਪਡੇਟ ਕੀਤਾ",
    "Delete" : "ਹਟਾਓ",
    "Groups" : "ਗਰੁੱਪ",
    "undo" : "ਵਾਪਸ",
    "add group" : "ਗਰੁੱਪ ਸ਼ਾਮਲ",
    "Sharing" : "ਸਾਂਝ",
    "Login" : "ਲਾਗਇਨ",
    "Server address" : "ਸਰਵਰ ਐਡਰੈਸ",
    "Cancel" : "ਰੱਦ ਕਰੋ",
    "Password" : "ਪਾਸਵਰ",
    "Change password" : "ਪਾਸਵਰਡ ਬਦਲੋ",
    "Username" : "ਯੂਜ਼ਰ-ਨਾਂ",
    "Error" : "ਗਲਤੀ"
},
"nplurals=2; plural=(n != 1);");
